# Grid World Project

4 x 4 grid world.
0 indexed.
Terminal states at index 0 & 15 (top left & bottom right).
Reward of -1 at all state transitions.
Each State has four actions, up, down, left, right.
Each action deterministically causes the corresponding State Transitions.
Actions taking the agent off the grid just leave the agent in place.
Undiscounted Episodic Task.
Equiprobable random Policy.
